        PROGRAM BLGwind

        IMPLICIT NONE

        INTEGER n,i,j,k,imax,jmax,kmax
        REAL z, Cd, fc, delta_T, Ui, Vi, delta_T1
        REAL, Allocatable :: U(:,:,:), V(:,:,:), M(:,:,:), delta_U(:,:,:), delta_V(:,:,:),G(:,:,:),R(:)

        OPEN(5,file='input.dat',status='old')
        READ(5,*)imax,jmax,kmax

        Allocate(R(jmax))
        Allocate(U(imax,jmax,kmax), V(imax,jmax,kmax), M(imax,jmax,kmax))
        Allocate(delta_U(imax,jmax,kmax), delta_V(imax,jmax,kmax),G(imax,jmax,kmax))

        z       = 1000.0     !Height of Atmosphere(m)
        Cd      = 0.01       !(drag coefficient)
        fc      = 0.0001    !Coriolis Parameter
        delta_T1= 3600.0     !time step(sec)(1 hr)

        DO j=1,jmax         ! j along the radius, i along azimuth
          R(j) = 500000.0   !Radius of Curvature(m)
        ENDDO

        DO k=1,kmax
         DO j=1,jmax
          DO i=1,imax
            G(i,j,k)= 20.0 !50.0       !Geostrophic Wind(m/s)
          ENDDO
         ENDDO
        ENDDO

        !Assume U and V equal zero first
        Ui=0.0
        Vi=0.0
        WRITE(*,*) " " 
        WRITE(*,*) "   BOUNDARY LAYER GRADIENT WIND!"    
        WRITE(*,*) "Iteration      Vt(m/s)     Ur(m/s)     M(m/s)   delta U     delta V"

        n=0
        Ui=0
        Vi=0

        DO k=1,kmax
         DO j=1,jmax
          DO i=1,imax
           M(i,j,k)=0
          ENDDO
         ENDDO
        ENDDO

        DO k=1,kmax
         DO j=1,jmax
          DO i=1,imax 
             DO WHILE (n.LE.20)     ! iterative loop

                IF (n.EQ.0) THEN
                        delta_T = 0.0
                ELSE IF (n>0) THEN
                        delta_T =delta_T1 
                ENDIF

                U(i,j,k) = Ui + delta_T * ((fc * Vi) -  (Cd * M(i,j,k) * Ui)/(z) + (Vi * ABS(Vi))/(R(j)))

                V(i,j,k) = Vi + delta_T * ((fc * (G(i,j,k) - Ui)) - (Cd * M(i,j,k) * Vi)/z - Ui * ABS(Ui)/R(j))

                IF(n.EQ.0)THEN  
                        delta_U = 0.0
                ELSE IF(n>0)THEN
                        delta_U(i,j,k) = U(i,j,k) - Ui
                        delta_V(i,j,k) = V(i,j,k) - Vi
                ENDIF

                M(i,j,k) = SQRT((U(i,j,k))**2+(V(i,j,k))**2)

                Ui = U(i,j,k)
                Vi = V(i,j,k)


                n=n+1

                if(i==1 .and. j==1 .and. k==1)WRITE(*,38) n, U(i,j,k), V(i,j,k), M(i,j,k), delta_U(i,j,k), delta_V(i,j,k)

             ENDDO
          ENDDO
         ENDDO
        ENDDO

38      FORMAT(4X,I2,10X,F5.2,6X,F5.2,6X,F5.2,6X,F5.3,5X,F6.3)
        DeAllocate (U, V, M, delta_U, delta_V,G,R)

        END
